Learn R Programming

eLNNpaired (version 0.2.3)

getPara.orig:

Description

Translate re-parameterized parameters to original scale.

Usage

getPara.orig(
  delta1, 
  xi1, 
  lambda1, 
  nu1, 
  delta2, 
  xi2, 
  lambda2, 
  nu2, 
  lambda3, 
  nu3, 
  c1 = qnorm(0.95), 
  c2 = qnorm(0.05))

Arguments

delta1
log of the mean of the mean expression levels for gene probes in cluster 1 (over-expressed probes).
xi1
the value of the inverse function of the cumulative distribution function of the standard normal distribution at the point that is equal to the scalar in the variance of the mean expression levles for gene probes in cluster 1 (over-expressed probes).
lambda1
a parameter related to \(\alpha_1\), which is the shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 1 (over-expressed probes).
nu1
log of the rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 1 (over-expressed probes).
delta2
log of the negative mean of the mean expression levels for gene probes in cluster 2 (under-expressed probes).

xi2
the value of the inverse function of the cumulative distribution function of the standard normal distribution at the point that is equal to the scalar in the variance of the mean expression levles for gene probes in cluster 2 (under-expressed probes).
lambda2
a parameter related to \(\alpha_2\), which is the shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 2 (under-expressed probes).
nu2
log of the rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 2 (under-expressed probes).

lambda3
a parameter related to \(\alpha_3\), which is the shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 3 (non-differentially-expressed probes).
nu3
log of the rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 3 (non-differentially-expressed probes).
c1
the lower bound for \(\mu_g/\sqrt{\tau_g^{-1}}\) for cluster 1 (over-expressed probes). By default \(c_1=\Phi^{-1}(0.95)\).
c2
the upper bound for \(\mu_g/\sqrt{\tau_g^{-1}}\) for cluster 2 (under-expressed probes). By default \(c_2=\Phi^{-1}(0.05)\).

Value

A \(10\times 1\) vector of reparameterized parameters: \(\mu_1\), \(k_1\), \(\alpha_1\), \(\beta_1\), \(\alpha_3\), \(\beta_3\),

Details

We assume the following the Bayesian hierarchical models for the 3 clusters of gene probes. For cluster 1 (over-expressed gene probes): $$d_{gl}|\left(\mu_g, \tau_g\right)\sim N\left(\mu_g, \tau_g^{-1}\right),\\ \mu_g | \tau_g \sim N\left(\mu_1, k_1 \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_1, \beta_1\right). $$ For cluster 2 (under-expressed gene probes): $$d_{gl}|\left(\mu_g, \tau_g\right)\sim N\left(\mu_g, \tau_g^{-1}\right),\\ \mu_g | \tau_g \sim N\left(\mu_2, k_2 \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_2, \beta_2\right). $$ For cluster 3 (non-differentially-expressed gene probes): $$d_{gl}|\left(\tau_g\right)\sim N\left(0, \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_3, \beta_3\right). $$ For cluster 1, we add one constraint $$ \alpha_1>1+\beta_1\left( \frac{ c_1-\Phi^{-1}(0.05)\sqrt{k_1}}{\mu_1} \right)^2$$ based on $$ Pr\left(\frac{\mu_g}{\tau_g^{-1}}\leq c_1 | \tau_g^{-1}\right)<0.05, $$ where \(c_1=\Phi^{-1}(0.05)\) and \(\Phi\) is the cumulative distribution function of the standard normal distribution. For cluster 2, we add one constraint $$ \alpha_2>1+\beta_2\left( \frac{ c_2-\Phi^{-1}(0.95)\sqrt{k_2}}{\mu_2} \right)^2$$ based on $$ Pr\left(\frac{\mu_g}{\tau_g^{-1}} \geq c_2 | \tau_g^{-1}\right)<0.05, $$ where \(c_2=\Phi^{-1}(0.95)\) and \(\Phi\) is the cumulative distribution function of the standard normal distribution. To do unconstraint numerical optimization, we do parameter reparameterization: $$ \mu_1=\exp(\delta_1), k_1=\Phi(\xi_1), \beta_1=\exp(\nu_1),\\ \alpha_1=\exp(\lambda_1)+1+\beta_1\left( \frac{c_1-\Phi^{-1}(0.05)\sqrt{k_1}}{\mu_1} \right)^2,\\ \mu_2= -\exp(\delta_2), k_2=\Phi(\xi_2), \beta_2=\exp(\nu_2),\\ \alpha_2=\exp(\lambda_2)+1+\beta_2\left( \frac{c_2-\Phi^{-1}(0.95)\sqrt{k_2}}{\mu_2} \right)^2,\\ \beta_3=\exp(\nu_3), \alpha_3=\exp(\lambda_3). $$

References

Li Y, Morrow J, Raby B, Tantisira K, Weiss ST, Huang W, Qiu W. (2017), <doi:10.1371/journal.pone.0174602>

See Also

See Also as getRePara

Examples

Run this code
getPara.orig(
  delta1 = -0.690142787, 
  xi1 = -7.212004793, 
  lambda1 = -13.152520780, 
  nu1 = -2.199687707,
  delta2 = -0.168584053, 
  xi2 = 0.008683666, 
  lambda2 = -13.582936416, 
  nu2 = -2.671150369,
  lambda3 = 0.331454152, 
  nu3 = -2.339660241,
  c1 = qnorm(0.95), 
  c2 = qnorm(0.05)
)

Run the code above in your browser using DataLab