Learn R Programming

eLNNpaired (version 0.2.3)

getRePara:

Description

Parameter reparameterization.

Usage

getRePara(
  mu1, 
  k1, 
  alpha1, 
  beta1, 
  mu2, 
  k2, 
  alpha2, 
  beta2, 
  alpha3, 
  beta3, 
  c1 = qnorm(0.95), 
  c2 = qnorm(0.05))

Arguments

mu1
mean of the mean expression levels for gene probes in cluster 1 (over-expressed probes).
k1
scalar in the variance of the mean expression levles for gene probes in cluster 1 (over-expressed probes).
alpha1
shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 1 (over-expressed probes).
beta1
rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 1 (over-expressed probes).
mu2
mean of the mean expression levels for gene probes in cluster 2 (under-expressed probes).
k2
scalar in the variance of the mean expression levles for gene probes in cluster 2 (under-expressed probes).
alpha2
shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 2 (under-expressed probes).
beta2
rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 2 (under-expressed probes).
alpha3
shape parameter of the distribution of the variance of gene expression levels for gene probes in cluster 3 (non-differentially expressed probes).
beta3
rate parameter of the distribution of the variance of gene expression levels for gene probes in cluster 3 (non-differentially expressed probes).
c1
the lower bound for \(\mu_g/\sqrt{\tau_g^{-1}}\) for cluster 1 (over-expressed probes). By default \(c_1=\Phi^{-1}(0.95)\).
c2
the upper bound for \(\mu_g/\sqrt{\tau_g^{-1}}\) for cluster 2 (under-expressed probes). By default \(c_2=\Phi^{-1}(0.05)\).

Value

A \(10\times 1\) vector of reparameterized parameters: \(\delta_1\), \(\xi_1\), \(\lambda_1\), \(\nu_1\), \(\delta_2\), \(\xi_2\), \(\lambda_2\), \(\nu_2\), \(\lambda_3\), \(\nu_3\).

Details

We assume the following the Bayesian hierarchical models for the 3 clusters of gene probes. For cluster 1 (over-expressed gene probes): $$d_{gl}|\left(\mu_g, \tau_g\right)\sim N\left(\mu_g, \tau_g^{-1}\right),\\ \mu_g | \tau_g \sim N\left(\mu_1, k_1 \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_1, \beta_1\right). $$ For cluster 2 (under-expressed gene probes): $$d_{gl}|\left(\mu_g, \tau_g\right)\sim N\left(\mu_g, \tau_g^{-1}\right),\\ \mu_g | \tau_g \sim N\left(\mu_2, k_2 \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_2, \beta_2\right). $$ For cluster 3 (non-differentially-expressed gene probes): $$d_{gl}|\left(\tau_g\right)\sim N\left(0, \tau_g^{-1}\right),\\ \tau_g\sim \Gamma\left(\alpha_3, \beta_3\right). $$ For cluster 1, we add one constraint $$ \alpha_1>1+\beta_1\left( \frac{ c_1-\Phi^{-1}(0.05)\sqrt{k_1}}{\mu_1} \right)^2$$ based on $$ Pr\left(\frac{\mu_g}{\tau_g^{-1}}\leq c_1 | \tau_g^{-1}\right)<0.05, $$ where \(c_1=\Phi^{-1}(0.05)\) and \(\Phi\) is the cumulative distribution function of the standard normal distribution. For cluster 2, we add one constraint $$ \alpha_2>1+\beta_2\left( \frac{ c_2-\Phi^{-1}(0.95)\sqrt{k_2}}{\mu_2} \right)^2$$ based on $$ Pr\left(\frac{\mu_g}{\tau_g^{-1}} \geq c_2 | \tau_g^{-1}\right)<0.05, $$ where \(c_2=\Phi^{-1}(0.95)\) and \(\Phi\) is the cumulative distribution function of the standard normal distribution. To do unconstraint numerical optimization, we do parameter reparameterization: $$ \mu_1=\exp(\delta_1), k_1=\Phi(\xi_1), \beta_1=\exp(\nu_1),\\ \alpha_1=\exp(\lambda_1)+1+\beta_1\left( \frac{c_1-\Phi^{-1}(0.05)\sqrt{k_1}}{\mu_1} \right)^2,\\ \mu_2= -\exp(\delta_2), k_2=\Phi(\xi_2), \beta_2=\exp(\nu_2),\\ \alpha_2=\exp(\lambda_2)+1+\beta_2\left( \frac{c_2-\Phi^{-1}(0.95)\sqrt{k_2}}{\mu_2} \right)^2,\\ \beta_3=\exp(\nu_3), \alpha_3=\exp(\lambda_3). $$

References

Li Y, Morrow J, Raby B, Tantisira K, Weiss ST, Huang W, Qiu W. (2017), <doi:10.1371/journal.pone.0174602>

See Also

See Also as getPara.orig

Examples

Run this code

getRePara(
  mu1 = 5.015045e-01, 
  k1 = 2.756702e-13, 
  alpha1 = 2.192323e+00, 
  beta1 = 1.108378e-01,
  mu2 = -8.448602e-01, 
  k2 = 5.034642e-01, 
  alpha2 = 1.766274e+00, 
  beta2 = 6.917261e-02,
  alpha3 = 1.392992e+00, 
  beta3 = 9.636037e-02,
  c1 = qnorm(0.95),
  c2 = qnorm(0.05)
)


Run the code above in your browser using DataLab